package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````0!X```````!``````````'"Q````
M`````````$``.``)`$``&P`:``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````*2>````````I)X`````````
M`"````````$````&````V*L```````#8JR```````-BK(```````2`0`````
M``#0%```````````(````````@````8```#PJP```````/"K(```````\*L@
M``````#@`0```````.`!````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````>)<```````!XEP```````'B7````````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````-BK````````V*L@``````#8JR``
M`````"@$````````*`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50"EMU3$^_[F?:GMD.3$<T5@T"+P*Q$```!%````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA%N@0""@````!%````
M20```$T```!.````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\"ZXY)\PN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75
M[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[0PZEPM6I)N6I]VC:W^IG)OAIP(*
M"HH05Z/@^TD```````````````````````````````````````````,`"@`@
M&@``````````````````&0$``!(`````````````````````````X`$``!(`
M````````````````````````7P(``!(`````````````````````````-`(`
M`!(`````````````````````````$0```"``````````````````````````
M9@(``!(`````````````````````````ZP(``!(`````````````````````
M````O````!(`````````````````````````>P(``!(`````````````````
M````````BP$``!(`````````````````````````TP(``!(`````````````
M````````````RP(``!(`````````````````````````F````!(`````````
M````````````````K`,``!(`````````````````````````%`$``!(`````
M````````````````````EP(``!(`````````````````````````B0(``!(`
M````````````````````````3@(``!(`````````````````````````Y`(`
M`!(``````````````````````````0,``!(`````````````````````````
M;P$``!(`````````````````````````/0$``!(`````````````````````
M````R@```!(`````````````````````````N0$``!(`````````````````
M````````#0(``!(`````````````````````````10(``!(`````````````
M````````````'0(``!(`````````````````````````/`(``!(`````````
M````````````````I@$``!(`````````````````````````=`(``!(`````
M````````````````````VP$``!(`````````````````````````10,``!(`
M````````````````````````/@,``!(`````````````````````````2P$`
M`!(`````````````````````````]`(``!(`````````````````````````
M+0```"``````````````````````````JP(``!(`````````````````````
M````>````!(`````````````````````````^0$``!(`````````````````
M````````L@$``!(`````````````````````````IP```!(`````````````
M````````````9`$``!(`````````````````````````*@$``!(`````````
M````````````````:@```!(`````````````````````````'@$``!(`````
M````````````````````L@(``!(`````````````````````````FP$``!(`
M````````````````````````^````!(`````````````````````````;`(`
M`!(`````````````````````````U`$``!(`````````````````````````
M+P,``!(`````````````````````````"`,``!(`````````````````````
M````?0$``!(`````````````````````````AP```!(`````````````````
M````````-P,``!(`````````````````````````@@(``!(`````````````
M````````````/````"``````````````````````````W````!(`````````
M````````````````6P$``!(`````````````````````````P`(``!(`````
M````````````````````+P(``!(`````````````````````````\0$``!(`
M````````````````````````G0(``!(`````````````````````````4```
M`"``````````````````````````$@,``"(`````````````````````````
MD`(``!(`````````````````````````(0,``!(`````````````````````
M````M0,``!(`#0"P50```````'$`````````@P,``!(`#@#$5@``````````
M````````V@,``!(`#0#P10```````$0,````````4@,``!(`#0!`'```````
M`/<!````````B0,``!(`#0"`/@````````4`````````2`0``!(`#0"0/@``
M`````-8!````````0@0``!(`"@`@&@``````````````````=00``!(`#0!`
M4@```````&D#````````:`,``!``&``@L"``````````````````P0,``!(`
M#0!P0````````"0`````````]`,``!$`#P#05@````````0`````````=`,`
M`!``&`"HP"``````````````````0`0``!(`#0!`/0```````#``````````
M500``!(`#0!P1````````',!````````9P0``!(`#0#`0P```````'D`````
M````YP,``!``%P``L"``````````````````S@,``!(`#0"@0````````/$`
M````````5P,``!$`&`!(L"````````@`````````80,``!``%P`@L"``````
M````````````6`,``"$`&`!(L"````````@`````````*00``!$`%P`8L"``
M``````@`````````W0(``!$`&`!@L"````````@`````````>0,``!(`#0#`
M5@````````(`````````&00``!(`#0!05@```````&4`````````[0,``!(`
M#0!`'@```````"H`````````Z0,``"``%P``L"``````````````````"0$`
M`!$`&``@L"````````0`````````60,``"$`&`!(L"````````@`````````
MF@,``!(`#0!`1````````"0``````````P0``!(`#0#`/0```````+D`````
M````ZP```!$`&`!`L"````````$`````````,P0``!(`#0"@00```````!("
M`````````&QI8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K
M7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!L:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M
M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB
M8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M
M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L
M`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'
M3$E"0U\R+C(N-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR
M`$=,24)#7S(N-````````@`#``(``@````(``@````(````"``(````"````
M`@`"``0``@`"`````````````P`"``4``@````(``P`"``(````&````!P``
M``,``@``````````````!@```````@`#``(``@```````@`"``````````(`
M`@`#``8````"``(`!@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``@`!``(``0`"``$``0`!``$````"``$``0````$````!``$`Q`$``!``
M```@````=1II"0```P"+!`````````$`!0`3`@``$`````````"4D98&```'
M`)<$```0````=!EI"0``!@"B!```$````'(9:0D```4`K@0``!`````4:6D-
M```$`+H$```0````=1II"0```@"+!````````-BK(```````"`````````!`
M'P```````."K(```````"```````````'P````````BP(```````"```````
M```(L"```````!BP(```````"`````````#X60```````.BM(```````!@``
M``(``````````````/"M(```````!@````,``````````````/BM(```````
M!@````0```````````````"N(```````!@````4```````````````BN(```
M````!@````8``````````````!"N(```````!@````<``````````````!BN
M(```````!@````@``````````````""N(```````!@````D`````````````
M`"BN(```````!@````H``````````````#"N(```````!@````L`````````
M`````#BN(```````!@````P``````````````$"N(```````!@````T`````
M`````````$BN(```````!@````X``````````````%"N(```````!@````\`
M`````````````%BN(```````!@```!```````````````&"N(```````!@``
M`!$``````````````&BN(```````!@```!(``````````````'"N(```````
M!@```!,``````````````'BN(```````!@```!0``````````````("N(```
M````!@```!4``````````````(BN(```````!@```!8``````````````)"N
M(```````!@```!<``````````````)BN(```````!@```!@`````````````
M`*"N(```````!@```!D``````````````*BN(```````!@```!H`````````
M`````+"N(```````!@```!L``````````````+BN(```````!@```!P`````
M`````````,"N(```````!@```!T``````````````,BN(```````!@```!X`
M`````````````-"N(```````!@```!\``````````````-BN(```````!@``
M`"```````````````."N(```````!@```"$``````````````.BN(```````
M!@```"(``````````````/"N(```````!@```",``````````````/BN(```
M````!@```"0```````````````"O(```````!@```"4```````````````BO
M(```````!@```"8``````````````!"O(```````!@```"<`````````````
M`!BO(```````!@```"@``````````````""O(```````!@```"D`````````
M`````"BO(```````!@```"H``````````````#"O(```````!@```"L`````
M`````````#BO(```````!@```"P``````````````$"O(```````!@```"T`
M`````````````$BO(```````!@```"X``````````````%"O(```````!@``
M`"\``````````````%BO(```````!@```#```````````````&"O(```````
M!@```#$``````````````&BO(```````!@```#(``````````````'"O(```
M````!@```#,``````````````'BO(```````!@```#0``````````````("O
M(```````!@```#4``````````````(BO(```````!@```#8`````````````
M`)"O(```````!@```#<``````````````)BO(```````!@```#@`````````
M`````*"O(```````!@```#D``````````````*BO(```````!@```#H`````
M`````````+"O(```````!@```#L``````````````+BO(```````!@```#P`
M`````````````,"O(```````!@```#T``````````````,BO(```````!@``
M`#X``````````````-"O(```````!@```#\``````````````-BO(```````
M!@```$```````````````."O(```````!@```$$``````````````.BO(```
M````!@```$(``````````````/"O(```````!@```$,``````````````/BO
M(```````!@```$0``````````````""P(```````!0```%\`````````````
M`$"P(```````!0```&,``````````````$BP(```````!0```%8`````````
M`````&"P(```````!0```%H``````````````$B#[`A(BP75E"``2(7`=`7H
M(P$``$B#Q`C#````````_S62DR``_R64DR``#Q]``/\EDI,@`&:0_R62DR``
M9I#_)9*3(`!FD/\EDI,@`&:0_R6:DR``9I#_)9J3(`!FD/\EFI,@`&:0_R6:
MDR``9I#_):*3(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0
M_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@
M`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3(`!FD/\E
MHI,@`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3(`!F
MD/\EHI,@`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3
M(`!FD/\EHI,@`&:0_R6BDR``9I#_):*3(`!FD/\EHI,@`&:0_R6JDR``9I#_
M):J3(`!FD/\EJI,@`&:0_R6JDR``9I#_):J3(`!FD/\EJI,@`&:0_R6JDR``
M9I#_):J3(`!FD/\EJI,@`&:0_R6JDR``9I#_);*3(`!FD/\ELI,@`&:0_R6Z
MDR``9I#_);J3(`!FD/\ENI,@`&:0_R6ZDR``9I#_);J3(`!FD/\ENI,@`&:0
M_R7"DR``9I#_)<*3(`!FD/\EPI,@`&:0``````````!54TB#[#B)?"0<2(ET
M)!!(C7PD'$B)5"0(2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H\/[__TB+
M-;F2(`!(BST*DR``2(GRZ*(Y``"`/:N3(```=2_H7/[__TB%P$B)!?JC(``/
MA'P!``!(B<?H[/W__XL]9I,@`.BQ_O__QH#%"````(L]5),@`$B-'=P[``#H
MF/[__X"(P@0```*+/3N3(`#HAO[__X"(P@0```&+1"0<C7@%2&/_2,'G`^@<
M_O__2(M\)!!(B05XHR``O@4```#'!7&C(``$````2(L72(E8"$B-'84[``!(
M@\<(2(E8&$B)$$B+%=F2(`!(B5`0BU0D'(/Z`8U*!'X7D$R+#TQCQH/&`4B#
MQP@YSDZ)3,#X=>I(BSTSHR``2&/)2(TU^1\``$C'1,CX`````(/"`T4QP$B)
MP>@:_O__A<")PW112(L]!:,@`$B-;"0DZ#O]__](C3W'.0``,<!(B>[H"AD`
M`$B%P'0Z2(L]WJ(@`.CI_/__Z,3]__^)V$B+7"0H9$@S'"4H````=51(@\0X
M6UW#2(L]M*(@`.@'_O__B</KGTB+/9RB(`!(A?]T!^BJ-P``Z[-(C3T9.0``
M2(GNZ*D8``!(A<!(B<=(B05THB``=)7KV;\!````Z-;]___HD?S__V8/'X0`
M`````#'M28G17DB)XDB#Y/!05$R-!6HX``!(C0WS-P``2(T]W/W__^C/_/__
M]&8/'T0``$B-/:F1(`!(C06ID2``54@I^$B)Y4B#^`YV%4B+!7:/(`!(A<!T
M"5W_X&8/'T0``%W##Q]``&8N#Q^$``````!(C3UID2``2(TU8I$@`%5(*?Y(
MB>5(P?X#2(GP2,'H/T@!QDC1_G082(L%`9$@`$B%P'0,7?_@9@\?A```````
M7<,/'T``9BX/'X0``````(`]89$@``!U)TB#/=>0(```54B)Y70,2(L]ZI`@
M`.C]_/__Z$C___]=Q@4XD2```?/##Q]``&8N#Q^$``````!(C3VAC"``2(,_
M`'4+Z5[___]F#Q]$``!(BP5)D"``2(7`=.E52(GE_]!=Z4#___]!5T%62(U/
M.$%5051,C5=X55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)YDF)X&8/
M'T0``(L12(L!2(/!"$F#P!`/RHG32(G"2,'J($F)6/!)B=%(P>((2<'A&('B
M``#_`$6)R4P)RDF)P4C!Z"A)P>DX)0#_``!,"<I("=!)B4#X3#G1=:Y(C59H
M2('&:`(```\?`$B+`D@S0MA(@\((2#-"H$@S0I!(C0P`2,'H'T@)R(/@_TB)
M0A!(.?)UUDR+#TB+7R!,BU<03(M?&$B+;PA,B<I,B<A-B<Q(P>(%2,'H&TR)
MV4@)T$B)VD@#%"2)P$F)[4@#3"0(2<'E'DG!Y!Y(C900F7F"6DR)T$PQV$@A
MZ$PQV$@!T$B)ZDC!Z@)!B<=)"=5,B=),B?Y%B>U(P>8%3#'J3"'*3#'22(V,
M"IEY@EI,B?I(P>H;2`GRB=)(C3013(G*3(GY2,'J`DCWT4D)U$PAZ4&)\$6)
MY$PAX$@)P4R)T$@#1"002(V4`9EY@EI,B<%,B<!(P>$%2,'H&T@)R(G`2(T,
M`DR)^DR)^$C!Z`)(P>(>2`G"3(G`08G.B=)(]]!,(>!((=9,`VPD&$@)QDR)
M\$P#9"0@2,'H&TF-M#69>8):38GU2<'E!4P)Z(G`3(TL!DR)P$G!Z`)(P>`>
M20G`3(GP18GO18G`2/?02"'03"'!2`-4)"A("<%,B?A)C;0,F7F"6DR)^4C!
MZ!M(P>$%2`G(B<!(C0P&3(GP2<'N`DC!X!Y,B?Y)"<9(]]9!B<Q$B?!,(<9)
M(<5)"?5,B>9.C:PJF7F"6DR)XDC![AM(P>(%2`GR3(G^2<'O`DC!YAZ)TDP!
MZDD)]TV)Y42)_DGWU4&)UDDAQ4@A\4P)Z4P#1"0P2`-$)#A-C:P(F7F"6DV)
M\$R)\4G!X`5(P>D;3`G!B<E-C40-`$R)X4G![`)(P>$>20G,18G%1(GA38GT
M2??42"'*22'T2`-T)$!,">),C:00F7F"6DR)Z$R)ZDC!ZAM(P>`%2`G03(GR
M2<'N`DC!XAZ)P$D)UDP!X$2)\DV)[D&)Q$GWUDDAT$DASDT)\$Z-M`:9>8):
M3(GF38G@2<'H&TC!Y@5,"<9-B>A)P>T"2<'@'HGV30G%3`'V18GH38GE08GV
M2??53"'`22'53`GH2`-,)$A(`U0D4$R-K`&9>8):3(GQ3(GP2,'A!4C!Z!M(
M"<B)P$F-3`4`3(G@2<'L`DC!X!Y)"<1!B<U$B>!-B?1)]]1((<9-(<1,`T0D
M6$P)YDR-I#*9>8):3(GJ3(GN2,'N&TC!X@5("?),B?9)P>X"2,'F'HG220GV
M3`'B1(GV38GN08G42??62"'Q22'&3`GQ38VT")EY@EI-B>!,B>%)P>`%2,'I
M&TP)P8G)38T$#DR)Z4G![0)(P>$>20G-18G&1(GI38GE2??52"'*22'U3`GJ
M2`-$)&!(`W0D:$R-K!"9>8):3(GP3(GR2,'J&TC!X`5("=!,B>))P>P"2,'B
M'HG`20G43`'H1(GB38GT08G%2??422'022',2`-,)'!-">!.C:0&F7F"6DR)
M[DV)Z$G!Z!M(P>8%3`G&38GP2<'N`DG!X!Z)]DT)QDP!YD6)\$V)[D&)]$GW
MUDPAP$DAUDP)\$R-M`&9>8):3(GA3(G@2,'A!4C!Z!M("<B)P$F-#`9,B>A)
MP>T"2,'@'DD)Q4&)SD2)Z$V)Y4GWU4@AQDTAQ4P)[D@#5"1X3`.$)(````!,
MC:PRF7F"6DR)\DR)]DC![AM(P>(%2`GR3(GF2<'L`DC!YAZ)TDD)]$P!ZD2)
MYDV)]$&)U4GWU$@A\4DAQ$@#A"2(````3`GA38GL38V$")EY@EI,B>E)P>0%
M2,'I&TP)X8G)38TD"$R)\4G![@)(P>$>20G.18G@1(GQ38GN2??62"'*22'V
M2`.T))````!,"?)-B<9(C900F7F"6DR)P$G!Y@5(P>@;3`GPB<!,C30"3(GJ
M2<'M`DC!XAY)"=5$B?!$B>I-B<5)B<=)]]5)(=1)(<U-">Q)P><%38G%3HVD
M)IEY@EI(B<9)P>@"2,'N&TG!Y1Y(`XPDF````$P)_DT)Q8GV18GH38T\-$B)
MQDTAQDCWUDP#A"2H````2"'618G\2`.4)*````!)"?9,B>9.C;0QF7F"6DR)
MX4C!Y@5(P>D;2`GQB<E)C30.2(G!2,'H`DC!X1Y("<A!B?9),<5%,>]-B?5*
MC8PZH>O9;DR)\DG!Y05(P>H;3`GJB=),C2P13(GA2<'L`DC!X1Y(B<*)P$P)
MX46)[TV)]$@QRDG!Y!XQUDR)^DF-M#"AZ]EN38GX2,'J&TG!X`5,"<))P>X"
M2`.$)+````")TDT)]$R-!!9(B<J)R4PQXD@#C"2X````1(G&03'53HVL**'K
MV6Y(B?)(B?!(P>H;2,'@!4@)T$R)^DG![P)(P>(>B<!,"?I,`>A-B>5),=5!
MB<9%,>A.C:P!H>O9;DR)\4V)\$G!Z!M(P>$%3`G!28GP2,'N`DG!X!Z)R4D)
M\$2)YD@#M"3`````28G43`'IB=)-,<1!B<]$,>!,C:0&H>O9;DR)^$R)_DC!
M[AM(P>`%2`GP3(GV2<'N`DC!YAZ)P$P)]DP!X$@#E"3(````38G$08G%18G`
M23'T3`.$)-````!$,>%,C:0*H>O9;DR)ZDR)Z4C!Z1M(P>(%2`G*3(GY2<'O
M`DC!X1Z)TDP)^4P!XDF)]$DQS$&)UHGV1#'@2`.T)-@```!-C:0`H>O9;DV)
M\$R)\$G!X`5(P>@;3`G`B<!-C00$3(GH2<'M`DC!X!Y,">A)B<U%B<1),<6)
MR4@#C"3@````1#'J3(VL%J'KV6Y,B>9,B>)(P>8%2,'J&T@)\HG228UT%0!,
MB?))P>X"2,'B'DP)\DF)QD&)]4DQUHG`13'P3HVT`:'KV6Y,B>E-B>A(P>$%
M2<'H&T@#A"3H````3`G!38G@2<'L`DG!X!Z)R4T)X$F)U$P!\4TQQ$&)SHG2
M1#'F2`.4)/````!,C:0PH>O9;DR)\$R)]DC![AM(P>`%2`GP3(GN2<'M`DC!
MYAZ)P$P)[DV)Q4P!X$DQ]4&)Q$6)P$0QZ4P#A"3X````3(VL"J'KV6Y,B>),
MB>%(P>D;2,'B!4@)RDR)\4G![@)(P>$>B=),"?%)B?9,`>I),<Y!B=6)]D0Q
M\$V-M`"AZ]EN38GH3(GH2<'@!4C!Z!M,"<")P$V-!`9,B>!(P>`>2`.T)``!
M``!)P>P"3`G@28G,18G&23'$B<E(`XPD"`$``$0QXDR-I!:AZ]EN3(GV3(GR
M2,'F!4C!ZAM("?*)TDF--!1,B>I)P>T"2,'B'DP)ZDF)Q4&)]$DQU8G`2`.$
M)!`!``!%,>A.C:P!H>O9;DR)X4V)X$G!Z!M(P>$%3`G!38GP2<'N`DG!X!Z)
MR4T)\$F)UDP!Z4TQQD&)S8G21#'V3(VT,*'KV6Y,B>A,B>Y(P>X;2,'@!4@)
M\$R)YDG![`)(P>8>B<!,">9,`?!(`Y0D&`$``$V)Q$&)QD6)P$DQ]$P#A"0@
M`0``1#'A3(VD"J'KV6Y,B?),B?%(P>D;2,'B!4@)RDR)Z4G![0)(P>$>B=),
M">E)B?5,`>)),<U!B=2)]D0QZ$@#M"0H`0``38VL`*'KV6Y-B>!,B>!)P>`%
M2,'H&TP)P(G`38U$!0!,B?!)P>X"2,'@'DP)\$F)SD6)Q4DQQHG)2`.,)#`!
M``!$,?),C;06H>O9;DR)[DR)ZDC!Y@5(P>H;2`GRB=))C3063(GB2<'L`DC!
MXAY,">))B<1!B?9),=2)P$4QX$V)]$Z-A`&AZ]EN3(GQ2<'D!4C!Z1M(`X0D
M.`$``$P)X8G)38TD"$V)Z$G![0))P>`>30GH28G51(GA33'%B=)$,>Y)B<U(
MC;0PH>O9;DB)R$G!Y05(P>@;3`GHB<!,C2P&3(GV2<'N`DC!YAY,B<!,"?9%
MB>]("?!)(<1,B<!%B<!((?!!"<2XW+P;CTF)QDP#M"1``0``3`'R38G^3`'B
M38G\2<'F!4G![!M-"?1%B>1)`=1(B<I(P>D"2,'B'D6)YD@)T4B)\D@)RDDA
MU4B)\HGV2"'*00G52(G"2`.4)$@!``!,`<)-B?!,`>I-B?5)P>@;2<'E!4T)
MZ$6)P$D!T$R)^DG![P)(P>(>18G%3`GZ28G/20G732'\28G/B<E)(==%"?Q)
MB<=,`[PD4`$``$P!_DV)[TP!YDV)[$G!YP5)P>P;30G\18GD3`'F38GT2<'N
M`DG!Y!Y!B?=-"?1)B=9-">9-(?!)B=:)TDTAYD4)\$F)QDP#M"18`0``3`'Q
M38G^3`'!38GX2<'F!4G!Z!M-"?!%B<!,`<%-B>A)P>T"2<'@'D&)SDT)Z$V)
MY4T)Q4PA[DV)Y46)Y$TAQ40)[DF)Q4P#K"1@`0``3`'J38GU2`'R3(GV2<'E
M!4C![AM)"?5,B?Y)P>\"2,'F'D6)[4P)_DV)QTD!U4D)]T2)ZDPA^4V)QT6)
MP$DA]T0)^4F)QTP#O"1H`0``30'\28G73`'A28G42<'G!4G![!M-">=%B?])
M`<],B?%(P>$>2<'N`D6)_$P)\4F)]DD)SDTA]4F)]HGV22'.10GU28G&3`.T
M)'`!``!-`?!-B>9-`>A-B>5)P>8%2<'M&TT)[D6)]DT!QDF)T$C!Z@))P>`>
M18GU3`G"28G(20G032''28G(B<E)(=!%"<=)B<!,`X0D>`$``$P!QDV)Z$P!
M_DV)[TG!Z!M)P><%30GX18G`20'P3(GF2<'L`DC!YAY%B<=)"?1(B=9,">9)
M(?9(B=:)TDPAYD$)]DB)QD@#M"2``0``2`'Q3(G^3`'Q38G^2,'N&TG!Y@5)
M"?9,B>Y)P>T"2,'F'D6)]DP)[DV)Y4D!SDD)]42)\4TAZ$V)Y46)Y$DA]44)
MZ$F)Q4P#K"2(`0``3`'J28G-3`'"28G(2<'E!4G!Z!M-"<5-B?A)P>\"2<'@
M'D6)[4T)^$F)]TD!U4T)QT2)ZDTA_DF)]XGV32''10G^28G'3`.\))`!``!-
M`?Q)B==-`?1)B=9)P><%2<'N&TT)_D6)]DT!YDF)S$C!Z0))P>0>18GW3`GA
M38G$20G,32'E38G$18G`22',10GE28G$3`.D))@!``!,`>9-B?Q,`>Y-B?U)
MP>P;2<'E!4T)[$6)Y$D!]$B)UDC!Z@)(P>8>18GE2`GR2(G.2`G622'V2(G.
MB<E((=9!"?9(B<9(`[0DH`$``$P!QDV)Z$P!]DV)[DG!Z!M)P>8%30GP18G`
M20'P3(G^2<'O`DC!YAY%B<9,"?Y)B==)"?=-(?Q)B=>)TDDA]T4)_$F)QTP#
MO"2H`0``3`'Y38GW3`'A38GT2<'G!4G![!M-"?Q%B>1,`>%-B>Q)P>T"2<'D
M'D&)STT)[$F)]4T)Y4TAZ$F)]8GV32'E10GH28G%3`.L)+`!``!,`>I-B?U,
M`<)-B?A)P>4%2<'H&TT)Q4V)\$G![@))P>`>18GM30GP38GF20'530G&1(GJ
M3"'Q38GF18GD32'&1`GQ28G&3`.T)+@!``!,`?9)B=9(`?%(B=9)P>8%2,'N
M&TD)]D6)]DD!SDR)^4G![P)(P>$>1(GV3`GY38G'20G/32']38G'18G`22'/
M10G]28G'3`.\),`!``!-`?Q)B?=-`>Q)B?5)P><%2<'M&TT)_46)[4T!Y4F)
MU$C!Z@))P>0>18GO3`GB28G,20G432'F28G,B<E)(=1%">9)B<1,`Z0DR`$`
M`$T!X$V)_$T!\$V)_DG![!M)P>8%30GF18GV30'&28GP2,'N`DG!X!Y%B?1,
M"<9)B=!)"?!-(<5)B=")TDDA\$4)Q4F)P$P#A"30`0``2`.$)-@!``!,`<%-
MB>!,`>E-B>5)P>@;2<'E!4@!T$T)Q46)[4D!S4R)^4G![P)(P>$>18GH3`GY
M28GW3(G"20G/32'^28GWB?9)(<]%"?Y,`?!-B<9)P>8%2,'J&TD)UD6)]DD!
MQDR)X$G![`)(P>`>1(GR20G$N-;!8LI)B<=,`[PDX`$``$P!_DF)SXG)33'G
M13']28G73`'N28G52<'G!4G![1M-"?U-B<=)P>@"2<'G'D6)[4T)^$F)QTP#
MO"3H`0``20'U1(GN3`'Y38GG18GD33''13'^28GW3`'Q28GV2<'G!4G![AM-
M"?Y)B==(P>H"2<'G'D6)]DD)UTB)PD@#E"3P`0``20'.1(GQ3`'B38G$18G`
M33'\13'E28G,3`'J28G-2<'L&TG!Y05-">Q)B?5(P>X"2<'E'D6)Y$P)[DF)
MQ4P#K"3X`0``20'41(GB30'H38G]18G_23'U13'N28G530'P28G62<'M&TG!
MY@5-"?5)B<Y(P>D"2<'F'D6)[4D)SDB)P4@#C"0``@``30'%18GH3`'Y28GW
MB?9-,?=%,?Q-B<=,`>%-B<1)P><%2<'L&TT)YTF)U$6)_TG!Y!Y)`<](P>H"
M20G42(G"2`.4)`@"``!$B?E(`?),B?9%B?9,,>9!,?5(B<Y,`>I)B<U(P>X;
M2<'E!4D)]46)[4D!U4R)PDG!Z`)(P>(>1(GN20G02(G"2`.4)!`"``!,`?)-
MB>9%B>1-,<9%,?=)B?9,`?I)B?=)P>X;2<'G!4T)]TF)SDC!Z0))P>8>18G_
M20G.2(G!2`.,)!@"``!)`==$B?I,`>%-B<1%B<!-,?1%,>5)B=1,`>E)B=5)
MP>4%2<'L&TT)Y46)[4D!S4B)\4C![@)(P>$>18GL2`G.2(G!2`.,)"`"``!,
M`<%-B?!%B?9),?!%,<=-B>!,`?E-B>=)P>@;2<'G!4T)QTF)T$C!Z@))P>`>
M18G_20G02(G"2`.4)"@"``!)`<]$B?E,`?))B?:)]DTQQD4Q]4F)SDP!ZDF)
MS4G!Y@5)P>T;30GN18GV20'63(GB2<'L`DC!XAY%B?5)"=1(B<)(`Y0D,`(`
M`$@!\DR)QD6)P$PQYD$Q]TR)[DP!^DV)[TC![AM)P><%20GW2(G.2,'I`DC!
MYAY%B?]("<Y(B<%(`XPD.`(``$D!UT2)^DP!P4V)X$6)Y$DQ\$4QQDF)T$P!
M\4F)UDG!Z!M)P>8%30G&18GV20'.3(GI2<'M`DC!X1Y%B?!)"<U(B<%(`XPD
M0`(``$P!X4F)](GV33'L13'G38G$3`'Y38G'2<'L&TG!YP5-">=)B=1%B?])
MP>0>20'/2,'J`DD)U$B)PD@#E"1(`@``1(GY2`'R3(GN18GM3#'F03'V2(G.
M3`'R28G.2,'N&TG!Y@5)"?9%B?9)`=9,B<))P>@"2,'B'D2)]DD)T$B)PD@#
ME"10`@``3`'J38GE18GD33'%13'O28GU3`'Z28GW2<'M&TG!YP5-"?U)B<](
MP>D"2<'G'D6)[4P)^4F)QTP#O"18`@``20'51(GJ30'\38G'18G`23'/13'^
M28G730'T28G62<'G!4G![AM-"?Y)B?=(P>X"2<'G'D6)]DP)_DF)QTP#O"1@
M`@``30'T18GF30'X28G/B<E),?=%,?U-B?=-`>A-B?5)P><%2<'M&TT)_4F)
MUTC!Z@))P><>18GM3`GZ28G'3`.\)&@"``!-`>A%B<5,`?E)B?>)]DDQUT4Q
M_$V)[TP!X4V)[$G!YP5)P>P;30G\38GW2<'N`DG!YQY%B>1-"?Y)B<=,`[PD
M<`(``$P!X4&)S$P!_DF)UXG233'W2`.$)'@"``!$`?-%,?A-B>=(B5\@3`'&
M38G@2<'G!4G!Z!M-"?A(`=!,B?)$`<9-B>A)P>T"2<'@'DT)Q4V)X$G![`),
M,>I)P>`>10'K,=%(B?)-"<1(`<A(B?%(P>H;2,'A!0'N10'B2`G*2(EW"$R)
M5Q`!T$R)7QA!`<%(BX0DB`(``&1(,P0E*````$R)#W422('$F`(``%M=05Q!
M74%>05_#Z!+D__]F+@\?A```````2(7_#X2^````05=!5D%505154TB#[`A,
MBSUJ>2``387_=&,/M@>$P'1V/#UT<DF)_$F#Q`%!#[8$)(3`=`0\/77O02G\
M28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB3(GV2(G?Z#KC__^%P'4'
M0H`\(SUT+TB#Q0A(BUT`2(7;==I(@\0(,<!;74%<05U!7D%?PV8/'X0`````
M`$4QY.N@#Q\`3"G]2HU$(P%(P?T#08EM`$B#Q`A;74%<05U!7D%?PS'`PV8/
M'T0``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD!&:0,<!(B=Y(B>_H
M`____TB%P'0P2&-4)`1(BP5Z>"``2(T$T$B+4`A(A=)(B1!TTF:02(/`"$B+
M4`A(A=)(B1!U\.N^2(M$)`AD2#,$)2@```!U!TB#Q!A;7</HNN+__V:005=!
M5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(`<-(
MB=_H>>+__TB-="0428G$2(GO,<#H9_[__TB%P`^$#@$``$B)QTF)Q>A3XO__
M23G$#X;B````3&-T)!1)P>8##[9%`(3`#X2K`0``/#T/A*,!``!(B>CK#0\?
MA```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,UC'<@`$J-?"`"Z++B__](
MA<!)B08/A'@!``!(8U0D%$B+!6IW(`!(C4T!2(L4T`^V10`\/8@"=":$P'40
MZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`B`)UZL8"/3'`#Q]$```/
MM@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*`````^%#@$``$B#Q"A;74%<
M05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7LZ\)FD$R+/=%V(`!)@S\`
M#X2\````3(GX,=+K"P\?A```````1(GJ2(/`"$2-:@%(@S@`=>^-<@-(8_9(
MP>8#BP7/AB``A<!T.TR)_^C[X?__2(7`2(D%@78@``^$?0```$UCQ4B)P4Z-
M-,4`````2L=$P0@`````1(EL)!3ID?[__V:02(GWQP6#AB```0```.AVX?__
M2(7`=$--8\5,B?Y(B<=.C33%`````$R)1"0(3(GRZ*/A__],BT0D"$B)P4B)
M!11V(`#KI3'`Z7C^__^^$````$4Q[>EA____N/_____IWO[__^AOX/__#Q^`
M`````$%6055!5%532('LH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_
M`$B)_74Q2(N$))@```!D2#,$)2@````/A2D!``!(@<2@````6UU!7$%=05[#
M9BX/'X0``````.C3W___2(7`28G$=,))B>5,B>?H^.#__TB%P$B)PP^$I```
M`(![$RX/A+(```!(@\,32(GOZ,;?__](B=])B<;HN]___T&-?`8"2&/_Z&;@
M__](C0V[&P``28G&2(G'28G928GH2,?"_____[X!````,<#H^.#__[\!````
M3(GJ3(GVZ$C?__^#^/],B?=T$(M$)!@E`/```#T`0```=&CH^][__TR)]^CC
MWO__3(GGZ%O@__](A<!(B<,/A6/___\/'X``````3(GGZ'C?__](B>_H(-__
M_^GR_O__#Q\`#[9#%(3`#X0D____/"X/A3K___^`>Q4`#X02____Z2O___\/
M'T0``.B3_O__ZY;H]-[__V:09BX/'X0``````%-(B?N+/39T(`#H@=___TB-
MD/@!``!(B=Z_`0```.C]W___A<!T"3'`6\,/'T0``(L]"G0@`.A5W___BX`0
M`@``)0#P```]`$```'0=BSWM<R``Z#C?__^+@!`"```E`/```#T`H```=;U(
MB=^^`@```.B)W___A<`/E,`/ML!;PP\?1```9BX/'X0``````$%5051)B?Q5
M4TB-/5H:``!)B?6Z_P\``$B![!@0``!(B>9D2(L$)2@```!(B80D"!```#'`
MZ,[=__^%P'YRC5#_2(GC2&/J@#PL`'1;2&/H2(GJOB\```!(B=_H6-[__TB%
MP'1+BSU%<R``Z)#>__](B>E(B=I,B>9(B<?H_][__TB+A"0($```9$@S!"4H
M````=3=(@<08$```6UU!7$%=PV8/'T0``(72=:0/'T``BSWZ<B``Z$7>__],
MB>I,B>9(B<?HK]W__^NVZ(C=__](@^P(BSW6<B``Z"'>__](BQ7:<"``2(T-
M@QL``$B--849``!(B<=(@\0(Z1C>__](@^P(BSVF<B``Z/'=__](B<?HN?__
M_XL]DW(@`.C>W?__3(T%$!L``$B-%:`4``!(C35>&0``13')2(G'2(/$"$R)
MP>GWW?__#Q^``````%532('L*"```&1(BP0E*````$B)A"08(```,<#HI]S_
M_TR-#?T8``!(C0TK&0``08G`N@$0```QP+X!````2(GGZ"K>__^%P'AF2(VL
M)!`0``"Z`!```$B)YTB)[NA6W/__A<!(B<-X1XUX`4AC_^A$W?__2(7`=#=(
M8]M(B>Y(B<=(B=KH%MW__\8$&`!(BY0D&"```&1(,Q0E*````'432('$*"``
M`%M=PP\?1```,<#KVNA/W/__#Q^``````.D[____D&8N#Q^$``````!!5T%6
M055!5$F)]%532(G[2(T]@1@``$B!["@0``!D2(L$)2@```!(B80D&!```#'`
M2(UT)`SH]??__[XO````2(G?2(G%Z/W;__](A<!T/4B-/4H8``!(B=XQP.@?
M^?__2(G82(N,)!@0``!D2#,,)2@````/A58!``!(@<0H$```6UU!7$%=05Y!
M7\-(B=],C2W_%P``Z)3;__](C34+&```08G&3(GG3(UD)!!!@\8!Z*'<__])
MB<=F#Q]$``!-A?]TBT&`/P!-#T3]2(7M=!-,B?Y(B>_HT]O__X7`#X2I````
M3(G_Z$/;__^)PDB808!\!_\O=1H/'X``````@^H!2&/"08!\!_\O0<8$!P!T
M[40!\H'Z_P\```^/+O___TB#[`A(C0VB&```3(T-?!<``%--B?BZ`!```+X!
M````3(GG,<#H5-S__XL]/G`@`.B)V___2(V0^`$``$R)YK\!````Z)7:__^%
MP%I9=1V+/1EP(`#H9-O__XN`$`(``"4`\```/0"```!T%DB--1D7```Q_^B\
MV___28G'Z1S___^^`0```$R)Y^B?V___A<!UV4B-/>46``!,B>;HO/?__TR)
MY^B\VO__Z9/^___H8MK__V8N#Q^$```````/M@](B?B$R7082(U7`6:0@/DO
M#[8*2`]$PDB#P@&$R77N\\-FD&8N#Q^$``````!54TB#[`A(A?]T-0^V+TB)
M^T"$[70JZ`7:__](C50#_T@YTW(4ZT]F#Q^$``````!(@^H!2#G3=$>`.B]T
M\NLMOP(```#HCMK__TB%P`^$E0```+HN````9HD02(/$"%M=PV8/'T0``(`Z
M+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`_2]TNDB#Q`A(C3T/%@``6UWIX-G_
M_P\?A```````@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`$```=RM(C3T<;R``
M2(G>2(/"`;D`$```Z"O:__](@\0(2(T%`&\@`%M=PP\?1```2(/$"#'`6UW#
M#Q]$``!F+@\?A```````4TB-/9H5``!(@^Q`9$B+!"4H````2(E$)#@QP$B+
M!?46``!(C5PD#$B)1"002(L%[!8``$B)1"082(L%Z!8``$B)1"0@2(L%Y!8`
M`$B)1"0H#[<%X!8``&:)1"0P,<#HC/7__TB-/4`5```QP.A^]?__2(T].A4`
M`#'`Z'#U__](C3TU%0``,<#H8O7__TB-/2X5```QP.A4]?__2(T],!4``#'`
MZ$;U__](C3W7%```,<#H./7__TB-/2`5```QP.@J]?__2(T]'!4``#'`Z!SU
M__](C3T8%0``,<#H#O7__TB-/:@4```QP.@`]?__2(T]!A4``#'`Z/+T__](
MC3T!%0``,<#HY/3__TB-/?X4```QP$B)WN@#]/__2(7`=!%(C3W`%```2(G&
M,<#H/?7__TB-/>@4```QP$B)WNC<\___2(7`=!%(C3WD%```2(G&,<#H%O7_
M_TB-/=X4```QP$B)WNBU\___2(7`=$!(C3T1%```2(G&,<#H[_3__TB-->,4
M``!(C3TT%```,<#HVO3__TB+1"0X9$@S!"4H````=6=(@\1`6\,/'T``2(T]
MF!0``#'`2(G>Z%_S__](A<!T&DB-/1(4``!(B<8QP.B9]/__ZZ@/'X``````
M2(UT)"%(C3UT%```N0H```#SIG6,2(UT)"M(C3W>$P``,<#H:/3__^ET____
MZ!;7__\/'T``9BX/'X0``````$B#[!AD2(L$)2@```!(B40D"#'`BP4V;"``
M@_C_=!E(BTPD"&1(,PPE*````'5%2(/$&,,/'T``2(UT)`1(C3U[$P``,<#H
MM?+__TB%P'0@#[80@/HP#Y7`A-(/E<(/MM(AT(D%YVL@`.NT#Q]$```QP.OO
MZ(_6__\/'X``````2(/L".B'UO__B<?H6-;__TB%P'0+2(L`2(/$",,/'P`Q
MP.OT9I!F+@\?A```````05=!5DF)_D%5051,C2V5$P``55-,C26"$P``2(/L
M:&1(BP0E*````$B)1"18,<!(C05Q$P``2,=$)%``````2(UL)"!,C7PD'$B)
M1"0@2(T%2!,``$B)1"0H2(T%21,``$B)1"0P2(T%,Q,``$B)1"0X2(T%+!,`
M`$B)1"1`2(T%,A,``$B)1"1(ZR$/'T``2(G'Z"#7__](A<!T8TB#Q0A-A>1T
M-TV)Y4R+90A,B?XQP$R)[^B6\?__2(7`2(G#3(GV=`6`.`!UQC'`3(GO2(/%
M".C(\O__387D=<E(BT0D6&1(,P0E*`````^%?0```$B#Q&A;74%<05U!7D%?
MPTR)]^A(U?__2(G?2(E$)`CH.]7__TB+5"0(2(U\`@+HY-7__TB#[`A,C0V?
M$0``2(T-N1(``%-(Q\+_____2(G'38GPO@$```!(B40D&#'`Z&O6__],BU0D
M&$R)[S'`3(G6Z#GR__]86NDO____Z.74__\/'P!F+@\?A```````05=!5D%5
M051)B?U54TB-/201``!(@>R(@0``9$B+!"4H````2(F$)'B!```QP$B-!1D2
M``!(C6PD+$C'1"1``````$C'A"28`````````$C'1"1@`````$B)1"0P2(T%
MTA```$B)[DB)1"0X2(T%<1$``$B)1"1P2(T%7A$``$B)1"1X2(T%R!$``$B)
MA"2`````2(T%8!$``$B)A"2(````2(T%LA$``$B)A"20````2(T%BA$``$B)
M1"102(T%FQ$``$B)1"18,<#H`/#__TB%P'0)@#@`#X5B!```,<#H:_W__TB%
MP$B)PP^$;`0``$B)W^C7T___2(U\``'HA=3__X`[`$F)QDF)Q'0P9I!$#[8#
M2(T-31$``$R)YS'`2,?"_____[X!````2(/#`4F#Q`+H!]7__X`[`'723(UD
M)'!(C3V:$```ZQ$/'T``28/$"$F+/"1(A?]T,S'`2(GNZ&GO__](A<!(B<-T
MX8`X`'3<2(G'Z'3T__^%P'302(G?Z*#3__](A<!(B<-U6DB+7"0P2(7;#X1J
M`0``@#L`0;P!````=27I6@$``&:026/$2(M<Q#!(A=L/A$<!``!!@\0!@#L`
M#X0Z`0``2(G?Z!KT__^%P'362(G?Z$;3__](A<!(B<-TQDB)W^C>TO__3(GQ
MBS%(@\$$C9;__O[^]]8A\H'B@("`@'3HB=;![A#WPH"````/1-9(C7$"2`]$
MSHG60`#62(/9`TPI\42-O`@$!```36/_3(G_Z$;3__])B<1(C04J$```059,
MC0W[#@``2(T-$1```$F)V%!(Q\+_____O@$```!,B><QP.C*T___OL`!``!,
MB>?H_='__X/X_T%805D/A(````"+/9IG(`#HY=+__TB-D/@!``!,B>:_`0``
M`.AAT___A<`/A)D```!)BTT`2(L]KF<@`$B-%7<0``!-B>"^`0```#'`Z%#3
M__\QP$B+C"1X@0``9$@S#"4H````#X5."0``2('$B($``%M=05Q!74%>05_#
M#Q]$```QV^G;_O__D.A3T?__1(L(08/Y$0^$;O___TF+30!(BSU#9R``2(T5
MS`\``$V)X+X!````,<#HY=+__S'`ZY-F#Q^$``````"+/=IF(`#H)=+__XN`
M$`(``"4`\```/0!````/A4;___^+/;EF(`#H!-+__XN8%`(``.A9T?__.<,/
MA2C___^+/9MF(`#HYM'__XN`$`(``"7_`0``/<`!```/A0?___],B?_HT-'_
M_TB-/6$.``!(B<-(B>XQP.@$[?__2(7`#X3K`0``2(G'Z$O1__])BWT`2(G&
MZ+?T__](A<!(B<4/A,L!``!(B>_HT]#__X/X`WXV2&/02(T];PX``+D%````
M2(UT%?SSIG4>@_@$#X3$!@``@^@$2)B`?`7_+P^$M`8```\?1```,<#HD?G_
M_X7`=14Q]DB)[^B#T?__A<")!"0/A7$!``!(C36\#0``2(T]*0T``#'`,>WH
ML>W__^@DT/__2(T-/@X``$R-#<X,``!(Q\+_____38G@O@$```!(B=]12(T-
M^`T``%`QP.B<T?__6%KK4P\?A```````Z+//__^#.!%U4^C9S___2(T-\PT`
M`$B#[`B#Q0%,C0U\#```38G@2,?"_____U%(C0V\#0``55"^`0```$B)WS'`
MZ$G1__](@\0@OL`!``!(B=_H>,___X/X_W2C3(GGZ$O/__](C3T<#```2(G>
M,<#H^NS__TB)W^A2^?__2(G8Z:3]__]F+@\?A```````2(G'2(D$).@T^?__
M2(L$)$B)Q^C0S___Z7W]__](C3W>#```0;P!````ZQ4/'T``26/$08/$`4B+
M?,102(7_="DQP$B)[NA%Z___2(7`=."`.`!TVTB)Q^B+S___2(7`2(G#=,OI
M1_O__[\-````2(T=D0P``.E#^___#Q]$``!)BVT`Z2S^__],C;0D<`$``+H"
M````2,?&[O___T&)QXG'Z#G0__^Z!@```$R)]D2)_^A)S___@+PD<`$```!U
M#H"\)'$!``!##X2A!0``BSPD,=(Q]DR-K"2@````Z/W/__^XB:O-[TC'A"2@
M`````2-%9TC'A"2X````=E0R$$B)A"2H````N/[<NIA(QX0DR`````````!(
MB80DL````+CPX=+#2,>$)-``````````2(F$),````!)C44XQX0D&`$`````
M``!(B40D$&:0BSPDN@"```!,B?;HH,[__X7`2(G%08G`#XZS`0``2(N4),@`
M``!(8\6--,)(.?(/AXL!``!(BY0DT````$C!Z!U(B;0DR````$@!T$B)A"30
M````2&.$)!@!``"%P`^$3`$``$&X0````$B+="0002G`1#G%1`].Q4B-/`9,
MB?9)8\A(B<I)B<](B4PD".A-SO__BX0D&`$``$0!^(/X0(F$)!@!```/A5/_
M__]!B>A,B>]%*?A,BWPD"$2)1"0<Z"O2__]$BT0D'$T!]P\?`$&#^#\/CK@#
M``!!C4#`B40D','H!HG%B40D"$B#Q0%(P>4&3`']9BX/'X0``````$F+%TR)
M[TF#QT!(B90DV````$F+5\A(B90DX````$F+5]!(B90DZ````$F+5]A(B90D
M\````$F+5^!(B90D^````$F+5^A(B90D``$``$F+5_!(B90D"`$``$F+5_A(
MB90D$`$``.B%T?__3#G]=9"+1"0(1(M$)!S!X`9!*<!(BWPD$$ECT+E(````
M2(GN1(E$)`CH-\W__T2+1"0(1(F$)!@!``#I5?[__P\?1```38GWZ1C___\/
M'X0``````$B+C"30````2(U1`>EL_O__BSPDZ*?,__](BZPDR````$R+M"30
M````2(GH2,'H`X/@/XU0`4B8QH0$V````("#^C@/CY$"``"X.````"G02&/2
MB<%)C405.(/Y"`^#MP(``/;!!`^%9`,``(7)=`SVP0+&```/A6<#``!,B?!,
MB>]$B+0D$P$``$C!Z!A`B*PD%P$``$R-O"1``0``B(0D$`$``$R)\$R-K"0A
M`0``2,'H$(B$)!$!``!,B?!-C7<H2,'H"(B$)!(!``!(B>A(P>@8B(0D%`$`
M`$B)Z$C!Z!"(A"05`0``2(GH3(G]2,'H"(B$)!8!``#H,=#__TB+A"2@````
M2(G"B(0D(P$``$C!ZAA$#[;"B)0D(`$``$B)PDC!ZA"(E"0A`0``2(G"2(N$
M)*@```!(P>H(B)0D(@$``$B)PHB$)"<!``!(P>H8B)0D)`$``$B)PDC!ZA"(
ME"0E`0``2(G"2(N$)+````!(P>H(B)0D)@$``$B)PHB$)"L!``!(P>H8B)0D
M*`$``$B)PDC!ZA"(E"0I`0``2(G"2(N$)+@```!(P>H(B)0D*@$``$B)PHB$
M)"\!``!(P>H8B)0D+`$``$B)PDC!ZA"(E"0M`0``2(G"2(N$),````!(P>H(
MB)0D+@$``$B)PHB$)#,!``!(P>H8B)0D,`$``$B)PDC!ZA"(E"0Q`0``2(G"
M2,'J"(B4)#(!``#I#`````\?`$4/MD4`28/%`4B-#>`'``!(B>\QP$C'PO__
M__^^`0```$B#Q0+HGLO__TPY]7712(T%"P@``,:$)&@!````4$%72(T-Q0<`
M`$R-#8D&``"^`0```$V)X$C'PO____](B=\QP.A@R___65[I)OK__TV+;0A-
MA>T/A$3Y__],B>_HU,G__TB#^`,/AC+Y__])C70%_$B-/6X'``"Y!0```/.F
M20]$[>D6^?__3(G]Z>7\__^X0````$ACRBG028U,#3B)PG0/,<")QH/``3G0
MQ@0Q`'+S3(GOZ"S.__])C54XN0<````QP$B)U_-(J^EB_?__B<I(QP``````
M2,=$$/@`````2(U0"$B#XOA(*=`!R(/@^(/X"`^"-_W__X/@^#')B<Z#P0@Y
MP4C'!#(`````<N_I'/W__X"\)'(!``!!#X51^O__@+PD<P$``$,/A4/Z__^`
MO"1T`0``2`^%-?K__X"\)'4!``!%#X4G^O__1(L\)+H"````2,?&QO___T2)
M_^@@RO__NBD```!,B?9$B?_H,,G__TB-!:(&``!005;IFO[__Y#'``````#'
M1`C\`````.F9_/__,?]FB7P(_NF-_/__Z)3(__]FD&8N#Q^$``````!!5D%5
M05154TB#[!"+/<Y=(`!,C6PD!&1(BP0E*````$B)1"0(,<#H!,G__TB-/?`$
M``#&@+$````!3(GN,<#H/.3__TB%P'0)@#@Q#X1N`@``,<#H!^___XL]@5T@
M`.C,R/__2(TU^`4``+D+````N@$```!(B<?HB\C__TB%P`^$NP```(,]PVT@
M``%(BT`03(M@*`^.I@```#'MNP$```#K+P\?0`!)BW802(L%E6T@`$ACTTB+
M/-#H0<C__X7`=6V+!8=M(`"#PP&#Q0$YV'YCBST'72``Z%+(__\QR4ACU4R)
MYDB)Q^BJR/__2(7`=#U,BS!!BT8,)0`$(``]``0``'2BBSW47"``Z!_(__],
MB?:Y`@```#'22(G'Z(W'__](B<;KA`\?A```````BP4:;2``C5#_.>H/A#\!
M``"+/9E<(`#HY,?__TB--14%``"Y`P```+H!````2(G'Z*/'__](A<!(B<-T
M-4B+0!"+/6E<(`!(BRCHL<?__TB-%>0$``!(B<=(B>[H%\?__TB+0Q!(BQCV
M0PY`#X6*`0``BSTX7"``Z(/'__](C36[`P``N0,```"Z`0```$B)Q^A"Q___
M2(7`2(G#=#U(C3T<`P``,<!,B>[HH>+__TB%P$B)Q0^$%0$``$B+0Q"+/>M;
M(`!(BQCH,\?__TB)ZDB)QTB)WNB=QO__BSW/6R``Z!K'__](C3W+`@``QH"Q
M`````$R)[C'`Z%+B__](A<!(B<-(B04=;"``#X2/````OL`!``!(B=_HXL7_
M_XU0`8/Z`78)@_@1#X7M````2(M$)`AD2#,$)2@````/A=0```!(@\006UU!
M7$%=05[#@_@!#XZX_O__NP$```!FD(L]2EL@`(/#`>B2QO__3(GF2(G'Z)?%
M__\Y':%K(`!_W^F+_O__9BX/'X0``````(!X`0`/A(_]___I@_W__Y!(BSUQ
M:R``Z-3P__](A<!(B<-(B05O:R``#X52____2(T]4@0``#'`Z$/&__\/'P!(
MBP5!:R``BSW36B``2(LH2(M#$$B+&.@4QO__2(GN2(G?Z`GG___IW_[__XL]
MKEH@`.CYQ?__2(G>2(G'Z!;&___I6_[__^@\Q?__B<%(BP7S:B``2(T]%`0`
M`$B)VDB+,#'`Z-?%__\/'X``````55-(B?U(@^P(Z.+J__\/MA!(B<.$TG0:
M2(U``0\?0`"`^B\/MA!(#T382(/``832=>XQP.C7[?__2(7M=!Z%P'0:@'T`
M`'042(TU9P(``$B)W^@AQO__2#G8=`=(@\0(6UW#2(/$"$B)[UM=Z3_D__]F
M+@\?A```````#Q]$``!(C07162``2(7`=`Q(BPCIS,3__P\?0``QR>G!Q/__
MD$%7059!B?]!54%43(TE=E4@`%5(C2UV52``4TF)]DF)U4PIY4B#[`A(P?T#
MZ)_#__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!_Q3<2(/#`4@YZW7J2(/$
M"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#Q`C#`````0`"`"5S
M+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0
M051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0````!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(```````````<&5R;'AS:2YC`````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO
M=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD
M)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA
M;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD
M(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO
M<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I
M;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A
M<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!
M4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.
M5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L
M971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@
M)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I
M('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T
M.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY
M("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T
M*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M
M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D
M9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D
M(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T
M*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@
M)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB
M:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]
M"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z
M.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O
M<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U
M="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE
M("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM
M>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3
M<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE
M(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*
M?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O
M("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O
M9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8[
M"FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS
M>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I
M.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N
M86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]
M"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H
M)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N
M86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!
M3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@
M0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@
M)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D
M9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```````$;`SOD````&P```,B"
M__\P`0``R(3__X`&``#(AO__``$``/B'__]8`0``2)___Z@!```8H/__&`(`
M`)B@__](`@``Z*+__Y@"``!HI/__X`(``/BD__\``P``R*7__T`#``#XI?__
M6`,``$BF__]P`P``"*?__Z`#```8I___N`,``/BH__\8!```**G__S`$```H
MJO__@`0``$BL__^H!```R*S__\@$``#XK/__Z`0``'BN__](!0``R+K__P`&
M```XOO__2`8``+B^__^P!@``V+[__\@&``!(O___$`<````````4````````
M``%Z4@`!>!`!&PP'")`!!Q`4````'````,"%__\J```````````````4````
M``````%Z4@`!>!`!&PP'")`!```D````'````)"!__\0``````X01@X82@\+
M=PB``#\:.RHS)"(`````3````$0```"8AO__1A<```!"#A"/`D(.&(X#1@X@
MC01"#BB,!44.,(8&00XX@P='#M`%`QT7"@XX00XP00XH0@X@0@X80@X00@X(
M00L```!L````E````)B=___*`````$L.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T0.0`)S"@XX0\,.,$'&#BA"S`X@0LT.&$+.#A!"SPX(2@M<#CA!
MPPXP0<8.*$+,#B!"S0X80LX.$$+/#@@`````+`````0!``#XG?__?@````!!
M#A"&`D$.&(,#1PXP`FT*#AA!#A!!#@A!"P``````3````#0!``!(GO__20(`
M``!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=*#F`#)@$*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A$"P````!$````A`$``$B@__]T`0```$(.$(X"0@X8
MC0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+````
M```<````S`$``("A__^!`````$$.$(,":0H."$8+`E`."#P```#L`0``\*'_
M_]``````0@X0C0)"#AB,`T0.((8$00XH@P56#L`@`GP*#BA!#B!!#AA"#A!"
M#@A'"P`````4````+`(``("B__\P`````$0.$&<."``4````1`(``)BB__])
M`````$0.$'T."``L````7`(``-"B__^Y`````$$.$(8"00X8@P-'#L!``I\*
M#AA!#A!!#@A&"P`````4````C`(``&"C__\%``````````````!<````I`(`
M`%BC___6`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!U$.X"`"
M9`H..$$.,$$.*$(.($(.&$(.$$(."$$+`ID.Z"!/#O`@>0[H($$.X"`````4
M````!`,``-BD__\D``````````````!,````'`,``/"D___Q`````$$.$(8"
M00X8@P-$#B`"60H.&$$.$$$."$<+8@H.&$@.$$$."$T+>0H.&$@.$$$."$8+
M1`X80PX000X(`````"0```!L`P``H*7__Q("````00X0@P)+#E`#G@$*#A!!
M#@A%"P`````<````E`,``)BG__]Y`````$0.(&\*#@A%"P```````!P```"T
M`P``^*?__R0`````1`X06`H."$0+````````7````-0#```(J/__<P$```!"
M#A"/`D(.&(X#10X@C01"#BB,!4@.,(8&00XX@P=+#J`!`M8*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A!"V@.J`%/#K`!<0ZH`4$.H`$`````M````#0$```HJ?__
M1`P```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=.#L"#`@,S`@[(
M@P)2#M"#`F@.R(,"0@[`@P(";@H..$$.,$$.*$(.($(.&$(.$$(."$8+`XT!
M#LB#`D@.T(,"2`[(@P)!#L"#`F0.R(,"50[0@P)(#MB#`D$.X(,"4P[`@P(#
MO`4.R(,"0@[0@P)H#LB#`D$.P(,"`S8!"@[(@P)"#M"#`D8+`$0```#L!```
MP+3__VD#````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D0.0`-K`@H.,$$.
M*$$.($(.&$(.$$(."$$+`````#0````T!0``Z+?__W$`````00X0A@)!#AB#
M`T<.(`)7"@X800X000X(00M$#AA$#A!!#@@`````+````&P%``!`?O__]P$`
M``!!#A"&`D$.&(,#1`Y0`YP!"@X800X000X(00L`````%````)P%````N/__
M'P``````````````1````+0%```(N/__90````!"#A"/`D(.&(X#10X@C01"
M#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`%````/P%
M```PN/__`@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````0!\`````````'P``````````
M`````````0`````````!``````````$`````````Q`$````````!````````
M`!,"````````#``````````@&@````````T`````````Q%8````````9````
M`````-BK(```````&P`````````(`````````!H`````````X*L@```````<
M``````````@`````````]?[_;P````"8`@````````4`````````"`T`````
M```&`````````)`#````````"@````````#$!`````````L`````````&```
M```````5`````````````````````P````````#0K2````````<`````````
M&!,````````(``````````@'````````"0`````````8`````````!@`````
M``````````````#[__]O``````$```@`````_O__;P````"8$@```````/__
M_V\``````@````````#P__]O`````,P1````````^?__;P`````$````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````\*L@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````#X60```````$=#
M0SH@*%5B=6YT=2`U+C,N,2TR,75B=6YT=3$Q*2`U+C,N,2`R,#$V,#4R.`!'
M0T,Z("A58G5N='4@-2XS+C$M,31U8G5N='4R*2`U+C,N,2`R,#$V,#0Q,P``
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I
M;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YI;FET`"YP;'0`+G!L="YG;W0`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!P````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````@
M````````````````````!````````````````````"$````'`````@``````
M``!T`@```````'0"````````)`````````````````````0`````````````
M```````T````]O__;P(`````````F`(```````"8`@```````/0`````````
M!0`````````(````````````````````/@````L````"`````````)`#````
M````D`,```````!X"0````````8````"````"``````````8`````````$8`
M```#`````@`````````(#0````````@-````````Q`0`````````````````
M``$```````````````````!.````____;P(`````````S!$```````#,$0``
M`````,H`````````!0`````````"``````````(`````````6P```/[__V\"
M`````````)@2````````F!(```````"```````````8````"````"```````
M`````````````&H````$`````@`````````8$P```````!@3````````"`<`
M```````%``````````@`````````&`````````!T`````0````8`````````
M(!H````````@&@```````!H````````````````````$````````````````
M````>@````$````&`````````$`:````````0!H````````0````````````
M````````$``````````0`````````'\````!````!@````````!0&@``````
M`%`:````````Z`$```````````````````@```````````````````"(````
M`0````8`````````0!P```````!`'````````((Z```````````````````0
M````````````````````C@````$````&`````````,16````````Q%8`````
M```)````````````````````!````````````````````)0````!`````@``
M``````#05@```````-!6````````J$````````````````````@`````````
M``````````"<`````0````(`````````>)<```````!XEP```````.0`````
M```````````````$````````````````````J@````$````"`````````&"8
M````````8)@```````!$!@``````````````````"```````````````````
M`+0````.`````P````````#8JR```````-BK````````"```````````````
M``````@```````````````````#`````#P````,`````````X*L@``````#@
MJP````````@````````````````````(````````````````````S`````$`
M```#`````````.BK(```````Z*L````````(````````````````````"```
M`````````````````-$````&`````P````````#PJR```````/"K````````
MX`$````````&``````````@`````````$`````````"#`````0````,`````
M````T*T@``````#0K0```````#`"```````````````````(``````````@`
M````````V@````$````#``````````"P(````````+`````````@````````
M````````````"````````````````````.`````(`````P`````````@L"``
M`````""P````````B!```````````````````"````````````````````#E
M`````0```#`````````````````````@L````````%L`````````````````
M```!``````````$``````````0````,`````````````````````````>[``
E``````#N`````````````````````0``````````````````````
